summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/forms/widgets/kexidbform.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/forms/widgets/kexidbform.cpp')
-rw-r--r--kexi/plugins/forms/widgets/kexidbform.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/kexi/plugins/forms/widgets/kexidbform.cpp b/kexi/plugins/forms/widgets/kexidbform.cpp
index bcf28a58..17242953 100644
--- a/kexi/plugins/forms/widgets/kexidbform.cpp
+++ b/kexi/plugins/forms/widgets/kexidbform.cpp
@@ -125,13 +125,13 @@ KexiDBForm::~KexiDBForm()
KexiDataAwareObjectInterface* KexiDBForm::dataAwareObject() const { return d->dataAwareObject; }
-//tqrepaint all tqchildren widgets
+//repaint all children widgets
static void repaintAll(TQWidget *w)
{
TQObjectList *list = w->queryList(TQWIDGET_OBJECT_NAME_STRING);
TQObjectListIt it(*list);
for (TQObject *obj; (obj=it.current()); ++it ) {
- TQT_TQWIDGET(obj)->tqrepaint();
+ TQT_TQWIDGET(obj)->repaint();
}
delete list;
}
@@ -148,7 +148,7 @@ void
KexiDBForm::drawRects(const TQValueList<TQRect> &list, int type)
{
TQPainter p;
- p.tqbegin(TQT_TQPAINTDEVICE(this), true);
+ p.begin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -192,7 +192,7 @@ void
KexiDBForm::clearForm()
{
TQPainter p;
- p.tqbegin(TQT_TQPAINTDEVICE(this), true);
+ p.begin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -216,7 +216,7 @@ KexiDBForm::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint &poi
toPoint = to->parentWidget()->mapTo(this, to->pos());
TQPainter p;
- p.tqbegin(TQT_TQPAINTDEVICE(this), true);
+ p.begin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -234,7 +234,7 @@ KexiDBForm::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint &poi
TQPixmap pix2 = TQPixmap::grabWidget(to);
if((from != this) && (to != this))
- p.drawLine( from->parentWidget()->mapTo(this, from->tqgeometry().center()), to->parentWidget()->mapTo(this, to->tqgeometry().center()) );
+ p.drawLine( from->parentWidget()->mapTo(this, from->geometry().center()), to->parentWidget()->mapTo(this, to->geometry().center()) );
p.drawPixmap(fromPoint.x(), fromPoint.y(), pix1);
p.drawPixmap(toPoint.x(), toPoint.y(), pix2);
@@ -313,18 +313,18 @@ void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
if (it.current()->widget()->focusPolicy() & TQ_TabFocus) {
//this widget has tab focus:
it.current()->widget()->installEventFilter(this);
- //also filter events for data-aware tqchildren of this widget (i.e. KexiDBAutoField's editors)
- TQObjectList *tqchildren = it.current()->widget()->queryList(TQWIDGET_OBJECT_NAME_STRING);
- for (TQObjectListIt tqchildrenIt(*tqchildren); tqchildrenIt.current(); ++tqchildrenIt) {
- // if (dynamic_cast<KexiFormDataItemInterface*>(tqchildrenIt.current())) {
+ //also filter events for data-aware children of this widget (i.e. KexiDBAutoField's editors)
+ TQObjectList *children = it.current()->widget()->queryList(TQWIDGET_OBJECT_NAME_STRING);
+ for (TQObjectListIt childrenIt(*children); childrenIt.current(); ++childrenIt) {
+ // if (dynamic_cast<KexiFormDataItemInterface*>(childrenIt.current())) {
kexipluginsdbg << "KexiDBForm::updateTabStopsOrder(): also adding '"
- << tqchildrenIt.current()->className() << " " << tqchildrenIt.current()->name()
+ << childrenIt.current()->className() << " " << childrenIt.current()->name()
<< "' child to filtered widgets" << endl;
- //it.current()->widget()->installEventFilter(TQT_TQWIDGET(tqchildrenIt.current()));
- tqchildrenIt.current()->installEventFilter(this);
+ //it.current()->widget()->installEventFilter(TQT_TQWIDGET(childrenIt.current()));
+ childrenIt.current()->installEventFilter(this);
// }
}
- delete tqchildren;
+ delete children;
if (fromWidget) {
kexipluginsdbg << "KexiDBForm::updateTabStopsOrder() tab order: " << fromWidget->name()
<< " -> " << it.current()->widget()->name() << endl;